package
Version:
v0.0.0-...-509a8f4
Opens a new window with list of versions in this module.
Published: Mar 10, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Logger interface {
Println(...interface{})
Printf(string, ...interface{})
}
type ResponseJson struct {
Error bool `json:"error"`
Mode string `json:"mode"`
Page int `json:"page"`
Query string `json:"query"`
Results [][]string `json:"results"`
Size int `json:"size"`
}
type Result struct {
Host, Title, Ip, Domain, Port, Country string
Province, City, Country_name, Protocol string
Server, Banner, Isp, As_organization string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.